import React, { FC, useContext } from 'react';
import { Button, Checkbox, FormControlLabel } from '@material-ui/core';
import { addVehicle } from 'api/addVehicle';
import { getRoleObject } from 'api/getRoleObject';
import { InputField } from 'components/Auth/InputField/InputField';
import { Controller, SubmitHandler, useForm } from 'react-hook-form';
import { VehicleType } from 'types/VehicleType';

export const InsertVehicle: FC = () => {
  const { control, handleSubmit } = useForm<VehicleType>({
    defaultValues: {
      user: null,
      plateNumber: '',
      carModel: '',
      wheelchair: false,
    },
  });

  const onSubmit: SubmitHandler<VehicleType> = (values: VehicleType) => {
    getRoleObject().then((user) => {
      const newValues = values;
      newValues.owner = user.id;
      newValues.user = null;
      addVehicle(newValues);
    });
  };

  return (
    <form onSubmit={handleSubmit(onSubmit)} data-testid="Form">
      <input type="hidden" name="owner" />
      <input type="hidden" name="user" />
      <InputField
        name="plateNumber"
        control={control}
        label="Plate Number"
        type="text"
      />

      <InputField
        name="carModel"
        control={control}
        label="Car model"
        type="text"
      />

      <Button
        data-testid="Submit"
        type="submit"
        fullWidth
        variant="contained"
        color="primary"
      >
        Insert vehicle
      </Button>
    </form>
  );
};
